==> nextcloud-25.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/eu.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU informazioa ez dago eskuragarri",
    "Load average: {cpu} (last minute)" : "Batezbesteko karga: {cpu} (azken minutua)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totala: {memTotalBytes}/Erabiltzen: {memUsageBytes}",
    "RAM info not available" : "RAM informazioa ez dago eskuragarri",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totala: {swapTotalBytes}/Erabiltzen: {swapUsageBytes}",
    "SWAP info not available" : "SWAP informazioa ez dago eskuragarri",
    "Users" : "Erabiltzaileak",
    "Groups" : "Taldeak",
    "Links" : "Estekak",
    "Emails" : "E-postak",
    "Federated sent" : "Bidalitako federatuak",
    "Federated received" : "Jasotako federatuak",
    "Talk conversations" : "Talk elkarrizketak",
    "24 hours" : "24 ordu",
    "1 hour" : "Ordu 1",
    "5 mins" : "5 min",
    "Copy" : "Kopiatu",
    "Copied!" : "Kopiatua!",
    "Not supported!" : "Ez da onartzen!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "System" : "Sistema",
    "Monitoring" : "Jarraipena",
    "Monitoring app with useful server information" : "Monitorizazio aplikazioa zerbitzariaren informazio baliagarriarekin",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zerbitzariaren informazio baliagarria ematen du, CPU karga, RAM erabilera, diskoaren erabilera, erabiltzaile kopurua, etab. bezala.",
    "Operating System:" : "Sistema eragilea:",
    "CPU:" : "PUZ:",
    "Unknown Processor" : "Prozesatzaile ezezaguna",
    "Memory:" : "Memoria:",
    "Server time:" : "Zerbitzariaren ordua:",
    "Uptime:" : "Denbora aktibo:",
    "Temperature" : "Tenperatura",
    "Load" : "Karga",
    "Memory" : "Memoria",
    "Disk" : "Diskoa",
    "Mount:" : "Muntatzea:",
    "Filesystem:" : "Fitxategi-sistema:",
    "Size:" : "Tamaina:",
    "Available:" : "Erabilgarri:",
    "Used:" : "Erabilia:",
    "You will get a notification once one of your disks is nearly full." : "Jakinarazpen bat jasoko duzu zure diskoetariko bat ia beteta dagoenean.",
    "Files:" : "Fitxategiak:",
    "Storages:" : "Biltegiak:",
    "Free Space:" : "Leku librea:",
    "Network" : "Sarea",
    "Hostname:" : "Ostalari-izena:",
    "DNS:" : "DNS:",
    "Gateway:" : "Sarbidea:",
    "Status:" : "Egoera:",
    "Speed:" : "Abiadura:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Erabiltzaile aktiboak",
    "Total users:" : "Erabiltzaileak guztira:",
    "Shares" : "Partekatutakoak",
    "PHP" : "PHP",
    "Version:" : "Bertsioa:",
    "Memory limit:" : "Memoria muga:",
    "Max execution time:" : "Gehienezko exekuzio denbora:",
    "Upload max size:" : "Kargatzeko gehienezko tamaina:",
    "Extensions:" : "Hedapenak:",
    "Unable to list extensions" : "Ezin dira zerrendatu luzapenak",
    "Database" : "Datu-basea",
    "Type:" : "Mota:",
    "External monitoring tool" : "Kanpo jarraipen tresna",
    "You can connect an external monitoring tool by using this end point:" : " Kanpoko kontrol-tresna konektatu daiteke amaiera-puntu hau erabiliz:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "URL-aren amaieran \"?format=json\" eransteak emaitza JSON-en ematen du.",
    "To use an access token, please generate one then set it using the following command:" : "Sarbide-token bat erabiltzeko, sortu bat eta ezarri komando hau erabiliz:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ondoren, pasatu token-a \"NC-Token\" goiburuarekin goiko URLa kontsultatzerakoan.",
    "Load average" : "Batez besteko karga",
    "Last minute" : "Azken minutuan",
    "Memory info not available" : "Memoria informazioa ez dago eskuragarri",
    "Total" : "Guztira",
    "Current usage" : "Gaur egungo erabilera",
    "Mails" : "Posta",
    "Operating System" : "Sistema eragilea",
    "CPU" : "PUZa",
    "Server time" : "Zerbitzariaren ordua",
    "Uptime" : "Denbora aktibo",
    "Mount" : "Muntatzea",
    "Filesystem" : "Fitxategi-sistema",
    "Size" : "Tamaina",
    "Available" : "Erabilgarri",
    "Used" : "Erabilia",
    "Hostname" : "Ostalari-izena",
    "DNS" : "DNS",
    "Gateway" : "Atebidea",
    "Status" : "Egoera",
    "Speed" : "Abiadura",
    "MAC" : "MACa",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Memory Limit:" : "Memoria muga:",
    "Max Execution Time:" : "Gehienezko exekuzio denbora:",
    "To use an access token please generate one then set it using the following command:" : "Sarbide token bat erabiltzeko, sortu eta ezarri komando hau erabiliz:",
    "Files" : "Fitxategiak",
    "Storages" : "Biltegiak",
    "Free Space" : "Leku librea",
    "Total users" : "Erabiltzaileak guztira",
    "Version" : "Bertsioa",
    "Memory limit" : "Memoria muga",
    "Max execution time" : "Gehienezko exekuzio denbora",
    "Upload max size" : "Kargatzeko gehienezko tamaina",
    "Type" : "Mota",
    "You can connect an external monitoring tool by using this end point" : "Kanpoko kontrol-tresna konektatu daiteke amaiera-puntu hau erabiliz",
    "To use an access token, please generate one then set it using the following command" : "Sarbide token bat erabiltzeko, sortu eta ezarri komando hau erabiliz"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/eu.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "CPU informazioa ez dago eskuragarri",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Totala: {memTotalBytes}/Erabiltzen: {memUsageBytes}",
    "RAM info not available" : "RAM informazioa ez dago eskuragarri",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totala: {swapTotalBytes}/Erabiltzen: {swapUsageBytes}",
    "SWAP info not available" : "SWAP informazioa ez dago eskuragarri",
    "Copied!" : "Kopiatuta!",
    "Not supported!" : "Ez da onartzen!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "Unknown" : "Ezezaguna",
    "System" : "Sistema",
    "Monitoring" : "Jarraipena",
    "Monitoring app with useful server information" : "Monitorizazio aplikazioa zerbitzariaren informazio baliagarriarekin",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zerbitzariaren informazio baliagarria ematen du, CPU karga, RAM erabilera, diskoaren erabilera, erabiltzaile kopurua, etab. bezala.",
    "Operating System:" : "Sistema eragilea:",
    "CPU:" : "PUZ:",
    "Memory:" : "Memoria:",
    "Server time:" : "Zerbitzariaren ordua:",
    "Uptime:" : "Denbora aktibo:",
    "Temperature" : "Tenperatura",
    "Load" : "Karga",
    "Memory" : "Memoria",
    "Disk" : "Diskoa",
    "Mount:" : "Muntatzea:",
    "Filesystem:" : "Fitxategi-sistema:",
    "Size:" : "Tamaina:",
    "Available:" : "Erabilgarri:",
    "Used:" : "Erabilia:",
    "Files:" : "Fitxategiak:",
    "Storages:" : "Biltegiak:",
    "Free Space:" : "Leku librea:",
    "Network" : "Sarea",
    "Hostname:" : "Ostalari-izena:",
    "Gateway:" : "Sarbidea:",
    "Status:" : "Egoera:",
    "Speed:" : "Abiadura:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Erabiltzaile aktiboak",
    "Last hour" : "Azken ordua",
    "Shares" : "Partekatutakoak",
    "Users:" : "Erabiltzaileak:",
    "Groups:" : "Taldeak:",
    "Links:" : "Estekak:",
    "Emails:" : "E-postak:",
    "Federated sent:" : "Bidalketa federatua:",
    "Federated received:" : "Jasoketa federatua:",
    "Talk conversations:" : "Talk elkarrizketak:",
    "PHP" : "PHP",
    "Version:" : "Bertsioa:",
    "Memory limit:" : "Memoria muga:",
    "Max execution time:" : "Gehienezko exekuzio denbora:",
    "seconds" : "duela segundu batzuk",
    "Upload max size:" : "Igotzeko gehienezko tamaina:",
    "Extensions:" : "Hedapenak:",
    "Unable to list extensions" : "Ezin dira zerrendatu luzapenak",
    "Show phpinfo" : "Erakutsi phpinfo",
    "Database" : "Datu-basea",
    "Type:" : "Mota:",
    "External monitoring tool" : "Kanpo jarraipen tresna",
    "Copy" : "Kopiatu",
    "To use an access token, please generate one then set it using the following command:" : "Sarbide-token bat erabiltzeko, sortu bat eta ezarri komando hau erabiliz:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ondoren, pasatu token-a \"NC-Token\" goiburuarekin goiko URLa kontsultatzerakoan.",
    "Unknown Processor" : "Prozesatzaile ezezaguna"
},
"nplurals=2; plural=(n != 1);");
